pub struct CreateOrderHint {
pub long_token: StringPubkey,
pub short_token: StringPubkey,
}Expand description
Hint for CreateOrder.
Fields
long_token: StringPubkeyLong token.
short_token: StringPubkeyShort token.
Implementations
Sourceimpl CreateOrderHint
impl CreateOrderHint
Sourcepub fn is_collateral_long(
&self,
collateral: &Pubkey,
) -> Result<bool, SolanaUtilsError>
pub fn is_collateral_long( &self, collateral: &Pubkey, ) -> Result<bool, SolanaUtilsError>
Returns whether the given token is long token or short token.
Errors
- Returns Error if the given
collateralis not one of the specified long or short tokens.